@@ -7,10 +7,10 @@ __description__ = "Async Crypto API for humans"
 
 __github__ = "https://github.com/ErVinTract/AioCrypto"
 
-__release__ = "1.0.3"
-__version__ = "1.0.3b"
+__version__ = '1.0.6'
+__release__ = '1.1b'
 
 
-from .Errors import *
+from .errors import *
 from .types import *
 from .app import *
