@@ -1,31 +1,31 @@
-from aiocrypto import App, Invoice, Balance, Currency, Transfer, ExchangeRate, Unauthorized, __release__
-from aiocrypto.types import Hostnames
+from aiocrypto import App, Invoice, Balance, Currency, Transfer, ExchangeRate, Unauthorized, __version__
+from aiocrypto.types import Hostnames, Assets
 
 from aiohttp import ClientSession
 
-from typing import List
+from typing import List, Union, Optional
 
 
-class CryptoApi():
-    def __init__(self, token=None, hostname: str = Hostnames.MAIN_NET) -> None:
+class CryptoApi:
+    def __init__(self, token, hostname: str = Hostnames.MAIN_NET) -> None:
         """
         ### Init CryptoPay api
 
         * async class CryptoApi
 
         ### Args:
-            token (str): [CryptoPay api token from @CryptoBot or @CryptoTestnetBot]
+            token (str): CryptoPay api token from @CryptoBot or @CryptoTestnetBot
 
-            hostname (str, optional): [Api endpoint hostname]. Defaults to Hostnames.MAIN_NET.
+            hostname (str, optional): Api endpoint hostname. Defaults to Hostnames.MAIN_NET.
 
-            delay (int, optional): [Not implemented, wait for version 0.2b]. Default is a 1
+            delay (int, optional): Not implemented, wait for version 1.2, zero by default
         """
 
         self._token = token
         self._hostname = hostname
         self._client: ClientSession = ClientSession(
             base_url=self._hostname, headers={
-                'Crypto-Pay-API-Token': self._token, 'user-agent': f'AioCrypto alpha {__release__}', }
+                'Crypto-Pay-API-Token': self._token, 'user-agent': f'AioCrypto Stable {__version__}', }
         )
 
     def _raise(self, response: dict) -> Exception:
@@ -44,6 +44,14 @@ class CryptoApi():
             else:
                 raise response
 
+    @classmethod
+    def _validate_asset(cls, asset):
+        assert asset in Assets.__annotations__.keys()
+
+    @classmethod
+    def _clear_dict(cls, dict_: dict):
+        return {key: value for key, value in dict_.items() if value is not None}
+
     async def get_me(self) -> App:
         """
         ### About
@@ -57,15 +65,15 @@ class CryptoApi():
         """
 
         async with self._client.get(url='/api/getMe') as response:
-            data__json = await response.json()
-            self._raise(response=data__json)
+            resp = await response.json()
+            self._raise(response=resp)
 
-            return App(**data__json['result'])
+            return App(**resp['result'])
 
     async def create_invoice(self,
                              asset: str,
                              amount: float,
-                             **kwargs: str | bool | int):
+                             **kwargs: Union[str, bool, int]):
         """
         ### About
 
@@ -74,7 +82,7 @@ class CryptoApi():
 
         Params
         -------
-            - asset (String): Supported assets: “BTC”, “TON”, “ETH” (testnet only), “USDT”, “USDC” and “BUSD”.
+            - asset (String): Supported assets: “BTC”, “TON”, “ETH”, “USDT”, “USDC” and “BUSD”.
             - amount (Float)
             - description (String): Optional. Description for the invoice. User will see this description when they pay the invoice. Up to 1024 characters.
             - hidden_message (String): Optional. Text of the message that will be shown to a user after the invoice is paid. Up to 2048 characters.
@@ -106,12 +114,12 @@ class CryptoApi():
         data['amount'] = amount
 
         async with self._client.get(url="/api/createInvoice", data=data) as response:
-            data__json = await response.json()
-            self._raise(response=data__json)
+            resp = await response.json()
+            self._raise(response=resp)
 
-            return data__json['result']
+            return resp['result']
 
-    async def transfer(self, user_id: int, asset: str, amount: float | str, spend_id: str, **kwargs) -> Transfer:
+    async def transfer(self, user_id: int, asset: str, amount: Union[float, str], spend_id: str, **kwargs) -> Transfer:
         """
         ### About
 
@@ -121,7 +129,7 @@ class CryptoApi():
         Params
         -------
             - user_id (Number): Telegram user ID. User must have previously used @CryptoBot (@CryptoTestnetBot for testnet).
-            - asset (String): Currency code. Supported assets: “BTC”, “TON”, “ETH” (testnet only), “USDT”, “USDC” and “BUSD”.
+            - asset (String): Currency code. Supported assets: “BTC”, “TON”, “ETH”, “USDT”, “USDC” and “BUSD”.
             - amount (String): Amount of the transfer in float. The minimum and maximum amounts for each of the support asset roughly correspond to the limit of 1-25000 USD. Use getExchangeRates to convert amounts. For example: 125.50
             - spend_id (String): Unique ID to make your request idempotent and ensure that only one of the transfers with the same spend_id is accepted from your app. This parameter is useful when the transfer should be retried (i.e. request timeout, connection reset, 500 HTTP status, etc). Up to 64 symbols.
             - comment (String): Optional. Comment for the transfer. Users will see this comment when they receive a notification about the transfer. Up to 1024 symbols.
@@ -143,10 +151,10 @@ class CryptoApi():
         data['spend_id'] = spend_id
 
         async with self._client.get(url='/api/transfer', data=data) as response:
-            data__json = await response.json()
-            self._raise(response=data__json)
+            resp = await response.json()
+            self._raise(response=resp)
 
-            return Transfer(**data__json['result'])
+            return Transfer(**resp['result'])
 
     async def get_balance(self) -> List[Balance]:
         """
@@ -154,36 +162,50 @@ class CryptoApi():
 
         Use this method to check your balance. Requires no parameters.
             If successful, returns information about the balance of the connected application.
+            - Supported assets: “BTC”, “TON”, “ETH”, “USDT”, “USDC” and “BUSD”.
 
         Returns
         --------
-            - Balance: list[Balance]
+            - list[Balance]: Balance list object
         """
 
         async with self._client.get(url='/api/getBalance') as response:
-            data__json = await response.json()
-            self._raise(response=data__json)
+            resp = await response.json()
+            self._raise(response=resp)
 
-            return [Balance(**balance) for balance in data__json['result']]
+            return [Balance(**balance) for balance in resp['result']]
 
-    async def get_invoices(self) -> List[Invoice]:
+    async def get_invoices(
+            self,
+            asset: Optional[str] = None,
+            invoice_ids: Optional[List[Union[str, int]]] = None,
+            status: Optional[str] = None,
+            offset: Optional[int] = None,
+            count: Optional[int] = None
+    ) -> List[Invoice]:
         """
         ### About
 
         Use this method to view active invoices.
-            If successful, returns a sheet with information about all invoices.
+            If successful, returns a sheet with information about all specified invoices.
 
         Returns
         --------
-            - Invoice: list[Invoice]
+            - list[Invoice]: Invoice list object
 
         """
+        if asset is not None:
+            self._validate_asset(asset)
 
-        async with self._client.get(url='/api/getInvoices') as response:
-            data__json = await response.json()
-            self._raise(response=data__json)
+        if invoice_ids is not None:
+            invoice_ids = ",".join(map(str, invoice_ids))
 
-            return [Invoice(**invoice) for invoice in data__json['result']['items']]
+        params = {"asset": asset, "invoice_ids": invoice_ids, "status": status, "offset": offset, "count": count}
+        async with self._client.get(url='/api/getInvoices', params=self._clear_dict(params)) as response:
+            resp = await response.json()
+            self._raise(response=resp)
+
+            return [Invoice(**invoice) for invoice in resp['result']['items']]
 
     async def get_exchange_rates(self) -> List[ExchangeRate]:
         """
@@ -194,13 +216,13 @@ class CryptoApi():
 
         Returns:
         --------
-            - List[ExchangeRate]: list[ExchangeRate]
+            - List[ExchangeRate]: ExchangeRate list object
         """
         async with self._client.get(url='/api/getExchangeRates') as response:
-            data__json = await response.json()
-            self._raise(response=data__json)
+            resp = await response.json()
+            self._raise(response=resp)
 
-            return [ExchangeRate(**exchange_rates) for exchange_rates in data__json['result']]
+            return [ExchangeRate(**rate) for rate in resp['result']]
 
     async def get_currencies(self) -> List[Currency]:
         """
@@ -211,31 +233,18 @@ class CryptoApi():
 
         Returns:
         --------
-            - List[Currency]: [Currency list object]
+            - List[Currency]: Currency list object
         """
 
         async with self._client.get(url='/api/getCurrencies') as response:
-            data__json = await response.json()
-            self._raise(response=data__json)
+            resp = await response.json()
+            self._raise(response=resp)
 
-            return [Currency(**currency) for currency in data__json['result']]
+            return [Currency(**currency) for currency in resp['result']]
 
     async def close(self) -> str:
-        """### Close client session
-
-        Example
-        -------
-
-        ```python
-        from aiocrypto import CryptoApi
-        from aiocrypto.types import Hostnames
-
-        api = CryptoApi(token="", hostname=Hostnames.TEST_NET)
-
-        me = await api.getMe()
-        print(me)
-        await api.close()
-
+        """
+        ### Close client session
         """
         await self._client.close()
-        return "Succes!"
+        return "Success!"
