@@ -128,8 +128,14 @@ class Hostnames:
     MAIN_NET: str = 'https://pay.crypt.bot'
     TEST_NET: str = 'https://testnet-pay.crypt.bot'
 
+        
 @dataclass
 class App:
     app_id: int
     name: str
     payment_processing_bot_username: str
+
+@dataclass
+class Status:
+    active: str = "active"
+    paid: str = "paid"
\ No newline at end of file
